package com.mortals.xhx.module.matter.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.matter.model.MatterDatumFileEntity;
import com.mortals.xhx.module.matter.model.MatterDatumFileQuery;
import com.mortals.xhx.module.matter.service.MatterDatumFileService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 材料附件
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("matter/datum/file")
public class MatterDatumFileController extends BaseCRUDJsonPhpController<MatterDatumFileService,MatterDatumFileForm,MatterDatumFileEntity,Long> {

    @Autowired
    private ParamService paramService;

    public MatterDatumFileController(){
        super.setFormClass(MatterDatumFileForm.class);
        super.setModuleDesc( "材料附件");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, MatterDatumFileForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "filetype", paramService.getParamBySecondOrganize("MatterDatumFile","filetype"));
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterDatumFile","source"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询材料附件
     */
    @PostMapping(value = "list")
    public String list(@RequestBody MatterDatumFileQuery query) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询材料附件列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增材料附件
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增材料附件错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑材料附件
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("材料附件模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存材料附件
     */
    @PostMapping(value = "save")
    public String save(@RequestBody MatterDatumFileEntity entity) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            form.setMatterDatumFile(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("材料附件模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除材料附件
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除材料附件错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看材料附件
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看材料附件错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 材料附件导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("材料附件导入模板下载错误", e);
        }
    }

    /**
     * 材料附件导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("材料附件导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 材料附件导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody MatterDatumFileQuery query) {
        try {
            MatterDatumFileForm form = new MatterDatumFileForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("材料附件导出错误", e);
        }
    }
}