package com.mortals.xhx.module.sms.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.sms.model.SmsTemplateEntity;
import com.mortals.xhx.module.sms.model.SmsTemplateQuery;
import com.mortals.xhx.module.sms.service.SmsTemplateService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 短信模板
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("sms/template")
public class SmsTemplateController extends BaseCRUDJsonPhpController<SmsTemplateService,SmsTemplateForm,SmsTemplateEntity,Long> {

    @Autowired
    private ParamService paramService;

    public SmsTemplateController(){
        super.setFormClass(SmsTemplateForm.class);
        super.setModuleDesc( "短信模板");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, SmsTemplateForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "type", paramService.getParamBySecondOrganize("SmsTemplate","type"));
        this.addDict(model, "source", paramService.getParamBySecondOrganize("SmsTemplate","source"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询短信模板
     */
    @PostMapping(value = "list")
    public String list(@RequestBody SmsTemplateQuery query) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询短信模板列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增短信模板
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增短信模板错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑短信模板
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("短信模板模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存短信模板
     */
    @PostMapping(value = "save")
    public String save(@RequestBody SmsTemplateEntity entity) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            form.setSmsTemplate(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("短信模板模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除短信模板
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除短信模板错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看短信模板
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看短信模板错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 短信模板导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("短信模板导入模板下载错误", e);
        }
    }

    /**
     * 短信模板导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("短信模板导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 短信模板导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody SmsTemplateQuery query) {
        try {
            SmsTemplateForm form = new SmsTemplateForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("短信模板导出错误", e);
        }
    }
}